<?php

namespace Drupal\cision_notify_pull\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\cision_notify_pull\CisionManagerInterface;
use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Class CisionFeedController.
 *
 * @package Drupal\cision_notify_pull\Controller
 */
class CisionFeedController extends ControllerBase {

  /**
   * The contentconnected manager.
   *
   * @var \Drupal\cision_notify_pull\CisionManagerInterface
   */
  protected $cisionManager;

  /**
   * Forum settings config object.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * {@inheritdoc}
   */
  public function __construct(CisionManagerInterface $cision_manager, ConfigFactoryInterface $config_factory) {
    $this->cisionManager = $cision_manager;
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('cision_notify_pull.cision_manager'),
      $container->get('config.factory')
    );
  }

  /**
   * handleCisionPull.
   *
   */
  public function handleCisionPull() {


    $config = $this->configFactory->get('cision_notify_pull.settings');
    $debug = $config->get('debug');

    $data = file_get_contents('php://input');

    if($debug) {
      \Drupal::logger('cision_notify_pull')->notice('Cision  @data', array(
        '@data' => $data
      ));
    }

    if (!empty($data)) {
      // sample xml for pull
      // $data = '<methodCall> <methodName>pushrelease.ping</methodName> <params> <param> <value>http://publish.ne.cision.com/v2.0/Release/GetDetail/EF242EB4C5C99992</value> </param> </params> </methodCall>';
       // sample xml for unpublish/delete
       /* $data = '<methodCall>
        <methodName>pushreleasedeleted.ping</methodName>
        <params>
        <param>
        <value>95EFBBA1B7BAA8A5</value>
        </param>
        <itemid>2375955</itemid>
        <encryptedid>29B08A3D28BC74D5</encryptedid>
        <deletedurl>http://publish.ne.cision.com/Release/GetDetail/95EFBBA1B7BAA8A5</deletedurl>
        </params>
        </methodCall>';*/


      $cision_xml = simplexml_load_string($data);
      $xml_mothod = $cision_xml->xpath('//methodCall/methodName');
      $methodName = $xml_mothod[0]->__toString();
      $xml_elements = $cision_xml->xpath('//params/param');
      if ($methodName == 'pushrelease.ping') {
        $this->cisionManager->processCisionFeeds($xml_elements);
        if($debug) {
          \Drupal::logger('cision_notify_pull')
            ->notice('Pull Cision feed is called from @data', array(
              '@data' => $data
            ));
        }
      }
      elseif ($methodName == "pushreleasedeleted.ping") {
        $this->cisionManager->deleteCisionFeeds($xml_elements);
        if($debug) {
          \Drupal::logger('cision_notify_pull')
            ->notice('Delete Cision feed is called from data:@data', array(
              '@data' => $data
            ));
        }
      }


      return [
        '#markup' => 'Data found',
      ];
    }
    else {
      return [
        '#markup' => 'No data found',
      ];
    }
  }

}
